@@ -82,11 +82,12 @@ public:
     bool crosses(const Polygon& p) const;
     Ring exteriorRing() const;
     std::vector<Ring> interiorRings() const;
+    void initGrids() const;
 
 private:
     void init();
     void removeSmallRings(double tolerance);
-    void removeSmallHoles(OGRGeometry *g, double tolerance);
+    void removeSmallHoles(double tolerance);
 
     std::unique_ptr<PrivateData> m_pd;
 };
